@@ -10,84 +10,72 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/2022Q1/bin',
- 'BINLIBDEST': '/2022Q1/lib/python3.9',
+ 'BINDIR': '/2022Q2/bin',
+ 'BINLIBDEST': '/2022Q2/lib/python3.9',
  'BLDLIBRARY': '-L. -lpython3.9',
- 'BLDSHARED': 'cc -pthread -shared -L. '
-              '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-              '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-              '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-              '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
-              '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-              '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-              '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-              '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
+ 'BLDSHARED': 'cc -pthread -shared -L. -Wl,-zrelro -L/2022Q2/lib '
+              '-Wl,-R/2022Q2/lib -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'x86_64-unknown-linux-gnu',
+ 'BUILD_GNU_TYPE': 'x86_64-chromeos-linux-gnu',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -D_FORTIFY_SOURCE=2 '
-           '-I/usr/include -I/2022Q1/include -I/2022Q1/include/ncurses '
-           '-I/2022Q1/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-           '-I/2022Q1/include -I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
-           '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-           '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
+           '-I/usr/include -I/2022Q2/include -I/2022Q2/include/ncurses '
+           '-I/2022Q2/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+           '-I/2022Q2/include -I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
+           '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+           '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                     '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
+ 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                     '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/2022Q1/include '
-                       '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
- 'CONFIGURE_LDFLAGS': '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-                      '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-                      '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 '
-                      '-Wl,-zrelro -L/2022Q1/lib -Wl,-R/2022Q1/lib',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/2022Q2/include '
+                       '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
+ 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/2022Q1' "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/2022Q2' "
                 "'--with-system-ffi' '--without-ensurepip' "
-                "'--without-pymalloc' '--prefix=/2022Q1' "
-                "'--build=x86_64-unknown-linux' '--host=x86_64-unknown-linux' "
-                "'--mandir=/2022Q1/man' '--enable-option-checking=yes' "
-                "'build_alias=x86_64-unknown-linux' "
-                "'host_alias=x86_64-unknown-linux' 'CC=cc' 'CFLAGS=-O2 "
-                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                "-I/2022Q1/include/ncurses -I/2022Q1/include/db4' "
-                "'LDFLAGS=-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 "
-                '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-                '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-                "-L/2022Q1/lib -Wl,-R/2022Q1/lib' 'LIBS=' "
-                "'CPPFLAGS=-I/usr/include -I/2022Q1/include "
-                "-I/2022Q1/include/ncurses -I/2022Q1/include/db4' "
-                "'PKG_CONFIG=/root/sda3/pkgsrc.2022Q1/lang/python39/work/.tools/bin/pkg-config' "
+                "'--without-pymalloc' '--prefix=/2022Q2' "
+                "'--build=x86_64-chromeos-linux' "
+                "'--host=x86_64-chromeos-linux' '--mandir=/2022Q2/man' "
+                "'--enable-option-checking=yes' "
+                "'build_alias=x86_64-chromeos-linux' "
+                "'host_alias=x86_64-chromeos-linux' 'CC=cc' 'CFLAGS=-O2 "
+                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                "-I/2022Q2/include/ncurses -I/2022Q2/include/db4' "
+                "'LDFLAGS=-Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/include -I/2022Q2/include "
+                "-I/2022Q2/include/ncurses -I/2022Q2/include/db4' "
+                "'PKG_CONFIG=/root/sda3/pkgsrc.2022Q2/lang/python39/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/root/sda3/pkgsrc.2022Q1/lang/python39/work/.buildlink/lib64/pkgconfig:/root/sda3/pkgsrc.2022Q1/lang/python39/work/.buildlink/lib/pkgconfig:/root/sda3/pkgsrc.2022Q1/lang/python39/work/.buildlink/share/pkgconfig'",
- 'CONFINCLUDEDIR': '/2022Q1/include',
- 'CONFINCLUDEPY': '/2022Q1/include/python3.9',
+                "'PKG_CONFIG_LIBDIR=/root/sda3/pkgsrc.2022Q2/lang/python39/work/.buildlink/lib64/pkgconfig:/root/sda3/pkgsrc.2022Q2/lang/python39/work/.buildlink/lib/pkgconfig:/root/sda3/pkgsrc.2022Q2/lang/python39/work/.buildlink/share/pkgconfig'",
+ 'CONFINCLUDEDIR': '/2022Q2/include',
+ 'CONFINCLUDEPY': '/2022Q2/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12/coverage.info',
- 'COVERAGE_REPORT': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12/lcov-report',
+ 'COVERAGE_INFO': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13/coverage.info',
+ 'COVERAGE_REPORT': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q1/include '
-             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -I/usr/include '
-             '-I/2022Q1/include -I/2022Q1/include/ncurses '
-             '-I/2022Q1/include/db4',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q2/include '
+             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -I/usr/include '
+             '-I/2022Q2/include -I/2022Q2/include/ncurses '
+             '-I/2022Q2/include/db4',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/2022Q1 /2022Q1/lib /2022Q1/lib/python3.9 '
-             '/2022Q1/lib/python3.9/lib-dynload',
- 'DESTLIB': '/2022Q1/lib/python3.9',
+ 'DESTDIRS': '/2022Q2 /2022Q2/lib /2022Q2/lib/python3.9 '
+             '/2022Q2/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/2022Q2/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/2022Q1/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/2022Q2/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -551,11 +539,11 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'x86_64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/2022Q1/include /2022Q1/include /2022Q1/include/python3.9 '
-                   '/2022Q1/include/python3.9',
- 'INCLUDEDIR': '/2022Q1/include',
- 'INCLUDEPY': '/2022Q1/include/python3.9',
+ 'HOST_GNU_TYPE': 'x86_64-chromeos-linux-gnu',
+ 'INCLDIRSTOMAKE': '/2022Q2/include /2022Q2/include /2022Q2/include/python3.9 '
+                   '/2022Q2/include/python3.9',
+ 'INCLUDEDIR': '/2022Q2/include',
+ 'INCLUDEPY': '/2022Q2/include/python3.9',
  'INSTALL': '/bin/install -c -o root -g root',
  'INSTALL_DATA': '/bin/install -c -o root -g root -m 644',
  'INSTALL_PROGRAM': '/bin/install -c -s -o root -g root -m 755',
@@ -565,36 +553,23 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared',
- 'LDFLAGS': '-L. -L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-            '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-            '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-            '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
-            '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-            '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-            '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-            '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
+ 'LDFLAGS': '-L. -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib -Wl,-zrelro '
+            '-L/2022Q2/lib -Wl,-R/2022Q2/lib',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -pthread -shared -L. '
-             '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-             '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-             '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-             '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
-             '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-             '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-             '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-             '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
+ 'LDSHARED': 'cc -pthread -shared -L. -Wl,-zrelro -L/2022Q2/lib '
+             '-Wl,-R/2022Q2/lib -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
  'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/2022Q1/lib/python3.9',
- 'LIBDIR': '/2022Q1/lib',
- 'LIBFFI_INCLUDEDIR': '/2022Q1/include',
+ 'LIBDEST': '/2022Q2/lib/python3.9',
+ 'LIBDIR': '/2022Q2/lib',
+ 'LIBFFI_INCLUDEDIR': '/2022Q2/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/2022Q1/lib/pkgconfig',
- 'LIBPL': '/2022Q1/lib/python3.9/config-3.9',
+ 'LIBPC': '/2022Q2/lib/pkgconfig',
+ 'LIBPL': '/2022Q2/lib/python3.9/config-3.9',
  'LIBPYTHON': '',
  'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
@@ -612,13 +587,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/2022Q1/lib/python3.9',
+ 'MACHDESTLIB': '/2022Q2/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'cc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/2022Q1/man',
+ 'MANDIR': '/2022Q2/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
@@ -644,11 +619,11 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/2022Q1/include',
- 'OPENSSL_LDFLAGS': '-L/2022Q1/lib',
+ 'OPENSSL_INCLUDES': '-I/2022Q2/include',
+ 'OPENSSL_LDFLAGS': '-L/2022Q2/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
+ 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -684,88 +659,76 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                              '-D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/2022Q1/include -I/2022Q1/include/ncurses '
-                             '-I/2022Q1/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/2022Q1/include '
-                             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                             '-I/2022Q2/include -I/2022Q2/include/ncurses '
+                             '-I/2022Q2/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
+                             '-I/usr/include -I/2022Q2/include '
+                             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
                              '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/2022Q1/include -I/2022Q1/include/ncurses '
-                             '-I/2022Q1/include/db4 -std=gnu99 -Wextra '
+                             '-I/2022Q2/include -I/2022Q2/include/ncurses '
+                             '-I/2022Q2/include/db4 -std=gnu99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include -I/2022Q1/include '
-                             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
-                             '-I/usr/include -I/2022Q1/include '
-                             '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                             '-I./Include -I/usr/include -I/2022Q2/include '
+                             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
+                             '-I/usr/include -I/2022Q2/include '
+                             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-              '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-              '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-              '-I/2022Q1/include/ncurses -I/2022Q1/include/db4',
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+              '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+              '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+              '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -std=gnu99 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -std=gnu99 '
                    '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/2022Q1/include -I/2022Q1/include/ncurses '
-                   '-I/2022Q1/include/db4 -I/usr/include -I/2022Q1/include '
-                   '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -fPIC '
+                   '-I/2022Q2/include -I/2022Q2/include/ncurses '
+                   '-I/2022Q2/include/db4 -I/usr/include -I/2022Q2/include '
+                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L. -L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-                    '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-                    '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-                    '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
-                    '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-                    '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-                    '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-                    '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q1/include '
-                '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
-                '-I/usr/include -I/2022Q1/include -I/2022Q1/include/ncurses '
-                '-I/2022Q1/include/db4',
+ 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib '
+                    '-Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q2/include '
+                '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
+                '-I/usr/include -I/2022Q2/include -I/2022Q2/include/ncurses '
+                '-I/2022Q2/include/db4',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L. -L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-               '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-               '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-               '-L/2022Q1/lib -Wl,-R/2022Q1/lib '
-               '-L/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-               '-Wl,-R/2022Q1/gcc7/lib/gcc/x86_64-unknown-linux/7.5.0 '
-               '-L/2022Q1/gcc7/lib64 -Wl,-R/2022Q1/gcc7/lib64 -Wl,-zrelro '
-               '-L/2022Q1/lib -Wl,-R/2022Q1/lib',
+ 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib -Wl,-zrelro '
+               '-L/2022Q2/lib -Wl,-R/2022Q2/lib',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q1/include '
-                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
+                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
                         '-std=gnu99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/2022Q1/include '
-                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 '
-                        '-I/usr/include -I/2022Q1/include '
-                        '-I/2022Q1/include/ncurses -I/2022Q1/include/db4 -fPIC',
+                        '-I./Include -I/usr/include -I/2022Q2/include '
+                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
+                        '-I/usr/include -I/2022Q2/include '
+                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -774,8 +737,8 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12',
- 'SCRIPTDIR': '/2022Q1/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13',
+ 'SCRIPTDIR': '/2022Q2/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -lintl -lpthread -ldl  -lutil -lm',
@@ -815,10 +778,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -841,9 +804,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12',
- 'abs_srcdir': '/root/sda3/pkgsrc.2022Q1/lang/python39/work/Python-3.9.12',
- 'datarootdir': '/2022Q1/share',
- 'exec_prefix': '/2022Q1',
- 'prefix': '/2022Q1',
+ 'abs_builddir': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13',
+ 'abs_srcdir': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13',
+ 'datarootdir': '/2022Q2/share',
+ 'exec_prefix': '/2022Q2',
+ 'prefix': '/2022Q2',
  'srcdir': '.'}
